@@ -1,5 +1,4 @@
 """ subpackage holding modules with tools """
 
 from . import collection, date, dictionary, ee_list, featurecollection, \
-              geometry, image, imagecollection, number, segmentation, \
-              string, array
\ No newline at end of file
+              geometry, image, imagecollection, number, string, array
\ No newline at end of file
